@@ -1,14 +1,14 @@
 use crate::commands::*;
-use clap::{AppSettings, ArgEnum, Clap};
+use clap::{ArgEnum, Parser};
 
 const VERSION: &str = env!("CARGO_PKG_VERSION");
 
-#[derive(Clap)]
+#[derive(Parser)]
 #[clap(
-version = VERSION,
-author = "Qonfucius team <contact+kcfg@qonfucius.team>",
-setting = AppSettings::ColoredHelp,
-license = "MIT"
+    version = VERSION,
+    author = "Qonfucius team <contact+kcfg@qonfucius.team>",
+    license = "MIT",
+    about = "Sometimes, you have to deal with many kubeconfig files. kcfg is here to help you !"
 )]
 /// Declares every available command and option of the program.
 pub struct KcfgApp {
@@ -16,20 +16,14 @@ pub struct KcfgApp {
     pub command: Command,
 }
 
-// TODO: remove this and move to Opts::about
-/// Sometimes, you have to deal with many kubeconfig files. kcfg is here to help you !
-#[derive(Clap, Debug, ArgEnum)]
+#[derive(Debug, ArgEnum, Parser)]
 pub enum Command {
-    #[clap(setting = AppSettings::ColoredHelp)]
     /// Initializes the environment relative to your current path
     Init(command_init::InitOptions),
-    #[clap(setting = AppSettings::ColoredHelp)]
     /// Find and use the correct KUBECONFIG
     Use(command_use::UseOptions),
-    #[clap(setting = AppSettings::ColoredHelp)]
     /// Duplicates the current KUBECONFIG file and uses it as KUBECONFIG
     Fork(command_fork::ForkOption),
-    #[clap(setting = AppSettings::ColoredHelp)]
     /// Generates tab-completion script for your shell
     Completions(command_completions::CompletionOptions),
 }
